//
//	Class definition for the Game State
//
//	- uses ldwGameState as base class
//

#ifndef THE_CONTENT_MAP_H
#define THE_CONTENT_MAP_H

//#include "ldwGameState.h"
//#include "WorldMap.h"
//#include "isola.h"
#include "theGameState.h"
#include "ldwGameWindow.h"
#define cWidthOfContentGrid 10
#define cHeightOfContentGrid 10
#define cWidthOfWorld 800
#define cHeightOfWorld 600
#define cLengthOfContentVector 85
#define widthOfBriarPiece		83
#define heightOfBriarPiece		73

#define CONTENT_GRADIENT_NULL 0x7fff
#define CONTENT_GRADIENT_MAX  (CONTENT_GRADIENT_NULL - 1)
#define CONTENT_GRADIENT_MIN  1

#define CONTENT_GRADIENT_COLUMNS (cWidthOfWorld/cWidthOfContentGrid)
#define CONTENT_GRADIENT_ROWS    (cHeightOfWorld/cHeightOfContentGrid)
#define CONTENT_GRADIENT_CELLCOUNT (CONTENT_GRADIENT_COLUMNS * CONTENT_GRADIENT_ROWS)
#define CONTENT_GRADIENT_NOTARGET (-1)

typedef struct 
{
	int targetX;
	int targetY;
	
	ldwUINT16 cell[CONTENT_GRADIENT_CELLCOUNT];		
}
ContentMapGradientType;

typedef enum
{
	eContentEmpty,
	eContentBlocked,
	eContentBlockedBoulder,
	eContentBlockedCoconuts,
	eContentBlockedLagoon,
	eContentBlockedIdol,
	eContentBlockedResearch,
	eContentBlockedTemple,
	eContentBlockedWell,
	eContentBlockedFood,
	eContentBlockedHut1,
	eContentBlockedHut2,
	eContentBlockedHut3,
	eContentBlockedHospital,
	eContentBlockedClothingHut,
	eContentBlockedScienceHut,
	eContentBlockedLoveshack,
	eContentBlockedFire,
	eContentBlockedBriar,
	eContentBlockedFirePit,
	eContentBlockedVines,
	eContentBlockedGongStatue,
	eContentBlockedCrate,
	eContentBlockedEndBlocked,
	
	eContentLeaving,
	eContentWrapN,
	eContentWrapS,
	eContentOcean,
	eContentShallow,

	eContentHotspotBlockage,
	eContentHotspotCemetery,
	eContentHotspotBoulder,
	eContentHotspotTreasure,
	eContentHotspotCoconuts,
	eContentHotspotDam,
	eContentHotspotTwistedWood,
	eContentHotspotIdol,
	eContentHotspotCenter,
	eContentHotspotPath,
	eContentHotspotPitcherPlant,
	eContentHotspotBlueRose,
	eContentHotspotBlackOrchid,
	eContentHotspotTigerLily,
	eContentHotspotPurpleDaisy,
	eContentHotspotWaxPlant,
	eContentHotspotDoor4,
	eContentHotspotDoor5,
	eContentHotspotDoor6,
	eContentHotspotResearch,
	eContentHotspotGarden,
	eContentHotspotShroom,
	eContentHotspotCollectable,
	eContentHotspotFarm,
	eContentHotspotFood,
	eContentHotspotTemple,
	eContentHotspotBeach,
	eContentHotspotWell,
	eContentHotspotCactus,
	eContentHotspotHut1,
	eContentHotspotHut2,
	eContentHotspotHut3,
	eContentHotspotHospital,
	eContentHotspotClothingHut,
	eContentHotspotLoveshack,
	eContentHotspotFirePit,
	eContentHotspotKindling,
	eContentHotspotFirewood,
	eContentHotspotBriar,
	eContentHotspotMosaic,
	eContentHotspotCenterMosaic,
	eContentHotspotDivingRock,
	eContentHotspotDivingRockTop,
	eContentHotspotStew,
	eContentHotspotVines,
	eContentHotspotCoveredPot,
	eContentHotspotSpeartips,
	eContentHotspotGongStatue,
	eContentHotspotCrateGong,
	eContentHotSpotEnd,

	eContentRedirectDivingRock,
	eContentRedirectResearchTable,
	eContentRedirectHospital,
	eContentRedirectDam,
	eContentRedirectEnd

} ContentTypeEnum;	



class theGameState;

class theContentMap 
{
public:


	static theContentMap * Get();
	static void Destroy();

	~theContentMap();
	ContentTypeEnum GetContent(ldwPoint where);
	ContentTypeEnum GetContent(int x, int y);

	bool IsBlocked(ldwPoint where);
	bool IsBlocked(int x, int y);

	void ShowContent();
	void InitContentMap();
	bool SetContent(ldwRect contentBlock, ContentTypeEnum contentType);
	void TestDraw();

	bool CreateTargetGradient(ContentMapGradientType *gradient,int x,int y);

	bool     OnGradientTarget(ContentMapGradientType *gradient,int x,int y);
	ldwPoint GetNextPointFromGradient(ContentMapGradientType *gradient,int x,int y);


	//array of villager's temporal data
	//tools for set/get of villager's persistant data

private:
	 ContentTypeEnum map[cLengthOfContentVector + 2][cLengthOfContentVector + 2];
	 // this is suppoed to be static but it wont compile

	ldwUINT16 mGradient[CONTENT_GRADIENT_CELLCOUNT];

	ldwUINT16 mMaxGradientValue;

protected:

	bool CellIsBlocked(int column,int row);

	//protected constructor.  called internally from Get()
	theContentMap();
	static theContentMap *mInstance;

	ldwImage *testBitmap;

	theGameState *gs;
	ldwGameWindow *gameWindow;

};

#endif
